================================
Command line interface reference
================================

Octavia-lib does not provide a CLI.

See the python-octaviaclient for the Octavia CLI:

    https://docs.openstack.org/python-octaviaclient/latest/
